---
sidebarDepth: 2
editLink: false
---
# Prefect Tasks
---
Tasks for interacting with the Prefect API
 ## StartFlowRun
 <div class='class-sig' id='prefect-tasks-prefect-flow-run-startflowrun'><p class="prefect-sig">class </p><p class="prefect-class">prefect.tasks.prefect.flow_run.StartFlowRun</p>(flow_name=None, project_name=None, parameters=None, wait=False, new_flow_context=None, run_name=None, scheduled_start_time=None, **kwargs)<span class="source"><a href="https://github.com/PrefectHQ/prefect/blob/master/src/prefect/tasks/prefect/flow_run.py#L15">[source]</a></span></div>

Task used to kick off a flow run using Prefect Core's server or Prefect Cloud.  If multiple versions of the flow are found, this task will kick off the most recent unarchived version.

**Args**:     <ul class="args"><li class="args">`flow_name (str, optional)`: the name of the flow to schedule; this value may also be         provided at run time     </li><li class="args">`project_name (str, optional)`: if running with Cloud as a backend, this is the project         in which the flow is located; this value may also be provided at runtime. If         running with Prefect Core's server as the backend, this should not be provided.     </li><li class="args">`parameters (dict, optional)`: the parameters to pass to the flow run being scheduled;         this value may also be provided at run time     </li><li class="args">`new_flow_context (dict, optional)`: the optional run context for the new flow run     </li><li class="args">`run_name (str, optional)`: name to be set for the flow run     </li><li class="args">`wait (bool, optional)`: whether to wait the triggered flow run's state; if True, this         task will wait until the flow run is complete, and then reflect the corresponding         state as the state of this task.  Defaults to `False`.     </li><li class="args">`scheduled_start_time (datetime, optional)`: the time to schedule the execution         for; if not provided, defaults to now     </li><li class="args">`**kwargs (dict, optional)`: additional keyword arguments to pass to the Task constructor</li></ul>

|methods: &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;|
|:----|
 | <div class='method-sig' id='prefect-tasks-prefect-flow-run-startflowrun-run'><p class="prefect-class">prefect.tasks.prefect.flow_run.StartFlowRun.run</p>(flow_name=None, project_name=None, parameters=None, idempotency_key=None, new_flow_context=None, run_name=None, scheduled_start_time=None)<span class="source"><a href="https://github.com/PrefectHQ/prefect/blob/master/src/prefect/tasks/prefect/flow_run.py#L60">[source]</a></span></div>
<p class="methods">Run method for the task; responsible for scheduling the specified flow run.<br><br>**Args**:     <ul class="args"><li class="args">`flow_name (str, optional)`: the name of the flow to schedule; if not provided,         this method will use the flow name provided at initialization     </li><li class="args">`project_name (str, optional)`: the Cloud project in which the flow is located; if         not provided, this method will use the project provided at initialization. If         running with Prefect Core's server as the backend, this should not be provided.     </li><li class="args">`parameters (dict, optional)`: the parameters to pass to the flow run being         scheduled; if not provided, this method will use the parameters provided at         initialization     </li><li class="args">`idempotency_key (str, optional)`: an optional idempotency key for scheduling the         flow run; if provided, ensures that only one run is created if this task is retried         or rerun with the same inputs.  If not provided, the current flow run ID will be used.     </li><li class="args">`new_flow_context (dict, optional)`: the optional run context for the new flow run     </li><li class="args">`run_name (str, optional)`: name to be set for the flow run     </li><li class="args">`scheduled_start_time (datetime, optional)`: the time to schedule the execution         for; if not provided, defaults to now</li></ul> **Returns**:     <ul class="args"><li class="args">`str`: the ID of the newly-scheduled flow run</li></ul> **Raises**:     <ul class="args"><li class="args">`ValueError`: if flow was not provided, cannot be found, or if a project name was         not provided while using Cloud as a backend</li></ul> **Example**:     <br><pre class="language-python"><code class="language-python">    <span class="token keyword">from</span> prefect.tasks.prefect.flow_run <span class="token keyword">import</span> StartFlowRun<br><br>    kickoff_task <span class="token operator">=</span> StartFlowRun<span class="token punctuation">(</span>project_name<span class="token operator">=</span><span class="token string">"</span><span class="token string">Hello, World!</span><span class="token string">"</span><span class="token punctuation">,</span> flow_name<span class="token operator">=</span><span class="token string">"</span><span class="token string">My Cloud Flow</span><span class="token string">"</span><span class="token punctuation">)</span><br>    <br></code></pre><br></p>|

---
<br>

 ## RenameFlowRun
 <div class='class-sig' id='prefect-tasks-prefect-flow-run-rename-renameflowrun'><p class="prefect-sig">class </p><p class="prefect-class">prefect.tasks.prefect.flow_run_rename.RenameFlowRun</p>(flow_run_id=None, flow_run_name=None, **kwargs)<span class="source"><a href="https://github.com/PrefectHQ/prefect/blob/master/src/prefect/tasks/prefect/flow_run_rename.py#L10">[source]</a></span></div>

Task used to rename a running flow.

**Args**:     <ul class="args"><li class="args">`flow_run_id (str, optional)`: The ID of the flow run to rename.     </li><li class="args">`flow_run_name (str, optional)`: The new flow run name.     </li><li class="args">`**kwargs (dict, optional)`: additional keyword arguments to pass to the Task constructor</li></ul>

|methods: &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;|
|:----|
 | <div class='method-sig' id='prefect-tasks-prefect-flow-run-rename-renameflowrun-run'><p class="prefect-class">prefect.tasks.prefect.flow_run_rename.RenameFlowRun.run</p>(flow_run_id, flow_run_name)<span class="source"><a href="https://github.com/PrefectHQ/prefect/blob/master/src/prefect/tasks/prefect/flow_run_rename.py#L30">[source]</a></span></div>
<p class="methods">**Args**:     <ul class="args"><li class="args">`flow_run_id (str, optional)`: The ID of the flow run to rename. If `None`,         the `flow_run_id` from `prefect.context` will be used as default value     </li><li class="args">`flow_run_name (str, optional)`: The new flow run name</li></ul> **Returns**:     <ul class="args"><li class="args">`bool`: Boolean representing whether the flow run was renamed successfully or not.</li></ul> **Raises**:     <ul class="args"><li class="args">`ValueError`: If `flow_run_id` is not provided and `flow_run_id` does not exist         in `prefect.context`     </li><li class="args">`ValueError`: If `flow_run_name` is not provided</li></ul> **Example**:     <br><pre class="language-python"><code class="language-python">    <span class="token keyword">from</span> prefect.tasks.prefect.flow_rename <span class="token keyword">import</span> FlowRenameTask<br><br>    rename_flow <span class="token operator">=</span> FlowRenameTask<span class="token punctuation">(</span>flow_name<span class="token operator">=</span><span class="token string">"</span><span class="token string">A new flow run name</span><span class="token string">"</span><span class="token punctuation">)</span><br>    <br></code></pre><br></p>|

---
<br>

 ## CancelFlowRun
 <div class='class-sig' id='prefect-tasks-prefect-flow-run-cancel-cancelflowrun'><p class="prefect-sig">class </p><p class="prefect-class">prefect.tasks.prefect.flow_run_cancel.CancelFlowRun</p>(flow_run_id=None, **kwargs)<span class="source"><a href="https://github.com/PrefectHQ/prefect/blob/master/src/prefect/tasks/prefect/flow_run_cancel.py#L10">[source]</a></span></div>

Task to cancel a flow run. If `flow_run_id` is not provided, `flow_run_id` from `prefect.context` will be used by default

**Args**:     <ul class="args"><li class="args">`flow_run_id (str, optional)`: The ID of the flow run to cancel     </li><li class="args">`**kwargs (dict, optional)`: additional keyword arguments to pass to the Task constructor</li></ul>

|methods: &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;|
|:----|
 | <div class='method-sig' id='prefect-tasks-prefect-flow-run-cancel-cancelflowrun-run'><p class="prefect-class">prefect.tasks.prefect.flow_run_cancel.CancelFlowRun.run</p>(flow_run_id=None)<span class="source"><a href="https://github.com/PrefectHQ/prefect/blob/master/src/prefect/tasks/prefect/flow_run_cancel.py#L28">[source]</a></span></div>
<p class="methods">**Args**:     <ul class="args"><li class="args">`flow_run_id (str, optional)`: The ID of the flow run to cancel</li></ul> **Returns**:     <ul class="args"><li class="args">`bool`: Whether the flow run was canceled successfully or not</li></ul></p>|

---
<br>


<p class="auto-gen">This documentation was auto-generated from commit <a href='https://github.com/PrefectHQ/prefect/commit/n/a'>n/a</a> </br>on December 16, 2020 at 21:36 UTC</p>